==> img0ch-2.1.11.zip: img0ch/_template/zeromin2/bbs_create_form.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/bbs_right_menu.cs" ?>

<div id="main">

<form id="bbsCreateContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=create_form&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板作成</a>
</div>

<h1>掲示板作成</h1>

<?cs if:Code0 ?><div class="" id="notify"></div><?cs /if ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>ディレクトリ名がありません</p></div><?cs /if ?>
<?cs if:Code3 ?><div class="noticeFailed" id="notify"><p>掲示板名がありません</p></div><?cs /if ?>
<?cs if:Code4 ?><div class="noticeFailed" id="notify"><p>掲示板副題がありません</p></div><?cs /if ?>
<?cs if:Code5 ?><div class="noticeFailed" id="notify"><p>不正なディレクトリ名です</p></div><?cs /if ?>
<?cs if:Code6 ?><div class="noticeFailed" id="notify"><p>予約されているディレクトリ名のため作成出来ません</p></div><?cs /if ?>
<?cs if:Code7 ?><div class="noticeFailed" id="notify"><p>そのディレクトリ名は既に作成されています</p></div><?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/metadata.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/validate.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
<!--
jQuery(function(){
jQuery("form#bbsCreateContainerForm").validate({
    "rules": {
        "dir": { "required": true },
        "BBS_TITLE": { "required": true },
        "BBS_SUBTITLE": { "required": true }
    },
    "messages": {
        "dir": { "required": "ディレクトリ名を入力してください" },
        "BBS_TITLE": { "required": "掲示板名を入力してください" },
        "BBS_SUBTITLE": { "required": "掲示板副題を入力してください" }
    },
    "showErrors": Zeromin2.getFormErrorHandler("以下の入力エラーがあります")
});
});
//-->
</script>

<p>
<label for="dir" title="dir">ディレクトリ名</label>
<input type="text" id="dir" name="dir" value="bbs" />
</p>

<p>
<label for="BBS_TITLE" title="BBS_TITLE">掲示板名</label>
<input type="text" id="BBS_TITLE" name="BBS_TITLE" value="掲示板＠名前募集中" />
</p>

<p>
<label for="BBS_SUBTITLE" title="BBS_SUBTITLE">掲示板副題</label>
<input type="text" id="BBS_SUBTITLE" name="BBS_SUBTITLE" value="何をするか意見を募集中です" />
</p>

<p>
<label for="category" title="category">カテゴリ</label>
<select id="category" name="category" title="category">
<?cs each:item = CategoryList ?><option value="<?cs var:html_escape(item.id) ?>"><?cs var:item.name ?></option>
<?cs /each ?>
</select>
</p>

<p>
<label for="inherit" title="inherit">掲示板設定の継承</label>
<select id="inherit" name="inherit" title="inherit">
<option value="">なし</option>
<?cs each:item = BBSList ?><option value="<?cs var:html_escape(item.id) ?>"><?cs var:item.name ?></option>
<?cs /each ?>
</select>
</p>

<p>
<label for="upload" title="upload">アップロードの許可</label>
<input type="checkbox" id="upload" name="upload" value="" />&nbsp;許可する
</p>

<div class="formFooter">
<input type="hidden" id="_<?cs var:html_escape(SessionName) ?>" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" id="_token" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" id="_class" name="class" value="bbs" />
<input type="hidden" id="_method" name="method" value="create" />
<input type="hidden" id="_OK" name="OK" value="load" />
<input type="hidden" id="_NG" name="NG" value="create_form" />
<input type="submit" value="作成" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.0.1.zip: img0ch/_template/zeromin2/bbs_create_form.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/bbs_right_menu.cs" ?>

<div id="main">

<form id="bbsCreateContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=create_form&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板作成</a>
</div>

<h1>掲示板作成</h1>

<?cs if:Code0 ?><div class="" id="notify"></div><?cs /if ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>ディレクトリ名がありません</p></div><?cs /if ?>
<?cs if:Code3 ?><div class="noticeFailed" id="notify"><p>掲示板名がありません</p></div><?cs /if ?>
<?cs if:Code4 ?><div class="noticeFailed" id="notify"><p>掲示板副題がありません</p></div><?cs /if ?>
<?cs if:Code5 ?><div class="noticeFailed" id="notify"><p>不正なディレクトリ名です</p></div><?cs /if ?>
<?cs if:Code6 ?><div class="noticeFailed" id="notify"><p>予約されているディレクトリ名のため作成出来ません</p></div><?cs /if ?>
<?cs if:Code7 ?><div class="noticeFailed" id="notify"><p>そのディレクトリ名は既に作成されています</p></div><?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/metadata.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/validate.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
<!--
jQuery(function(){
jQuery("#bbsCreateContainerForm").validate({
    "rules": {
        "dir": { "required": true },
        "BBS_TITLE": { "required": true },
        "BBS_SUBTITLE": { "required": true }
    },
    "messages": {
        "dir": { "required": "ディレクトリ名を入力してください" },
        "BBS_TITLE": { "required": "掲示板名を入力してください" },
        "BBS_SUBTITLE": { "required": "掲示板副題を入力してください" }
    },
    "showErrors": Zeromin2.getFormErrorHandler("以下の入力エラーがあります")
});
});
//-->
</script>

<p>
<label for="dir" title="dir">ディレクトリ名</label>
<input type="text" id="dir" name="dir" value="bbs" />
</p>

<p>
<label for="BBS_TITLE" title="BBS_TITLE">掲示板名</label>
<input type="text" id="BBS_TITLE" name="BBS_TITLE" value="掲示板＠名前募集中" />
</p>

<p>
<label for="BBS_SUBTITLE" title="BBS_SUBTITLE">掲示板副題</label>
<input type="text" id="BBS_SUBTITLE" name="BBS_SUBTITLE" value="何をするか意見を募集中です" />
</p>

<p>
<label for="category" title="category">カテゴリ</label>
<select id="category" name="category" title="category">
<?cs each:item = CategoryList ?><option value="<?cs var:html_escape(item.id) ?>"><?cs var:item.name ?></option>
<?cs /each ?>
</select>
</p>

<p>
<label for="inherit" title="inherit">掲示板設定の継承</label>
<select id="inherit" name="inherit" title="inherit">
<option value="">なし</option>
<?cs each:item = BBSList ?><option value="<?cs var:html_escape(item.id) ?>"><?cs var:item.name ?></option>
<?cs /each ?>
</select>
</p>

<p>
<label for="BBS_MODE" title="BBS_MODE">アップロードの許可</label>
<input type="checkbox" id="BBS_MODE" name="BBS_MODE" value="picture" />&nbsp;許可する
</p>

<div class="formFooter">
<input type="hidden" id="_<?cs var:html_escape(SessionName) ?>" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" id="_token" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" id="_class" name="class" value="bbs" />
<input type="hidden" id="_method" name="method" value="create" />
<input type="hidden" id="_OK" name="OK" value="load" />
<input type="hidden" id="_NG" name="NG" value="create_form" />
<input type="submit" value="作成" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
